@@ -1,5 +1,4 @@
-package    # Avoid PAUSE indexing.
-  PNI::Node::Perlfunc::Keys;
+package PNI::Node::Perlfunc::Keys;
 use PNI::Node::Mo;
 extends 'PNI::Node';
 
@@ -17,8 +16,8 @@ sub task {
     my $out  = $self->out;
 
     $in->is_hash or return $self->off;
-    my $hash_ref = $in->data;
-    my @keys     = keys( %{$hash_ref} );
+
+    my @keys = keys( $in->data );
 
     $out->data( \@keys );
 }
