@@ -1,5 +1,4 @@
-package    # Avoid PAUSE indexing.
-  PNI::Node::Perlfunc::Lc;
+package PNI::Node::Perlfunc::Lc;
 use PNI::Node::Mo;
 extends 'PNI::Node';
 
@@ -23,3 +22,4 @@ sub task {
 
 1
 
+
